@@ -4,7 +4,6 @@ import logging
 import os
 import platform
 import time
-import six
 
 from aws_xray_sdk import global_sdk_config
 from aws_xray_sdk.version import VERSION
@@ -456,10 +455,10 @@ class AWSXRayRecorder(object):
         try:
             return_value = wrapped(*args, **kwargs)
             return return_value
-        except Exception as exc:
-            exception = exc
+        except Exception as e:
+            exception = e
             stack = stacktrace.get_stacktrace(limit=self.max_trace_back)
-            six.raise_from(exc, exc)
+            raise
         finally:
             # No-op if subsegment is `None` due to `LOG_ERROR`.
             if subsegment is not None:
