@@ -1,4 +1,5 @@
 import logging
+from .conf import settings
 
 from aws_xray_sdk.core import xray_recorder
 from aws_xray_sdk.core.models import http
@@ -30,6 +31,14 @@ class XRayMiddleware(object):
         if check_in_lambda() and type(xray_recorder.context) == LambdaContext:
             self.in_lambda_ctx = True
 
+    def _urls_as_annotation(self):
+        if settings.URLS_AS_ANNOTATION == "LAMBDA" and self.in_lambda_ctx:
+            return True
+        elif settings.URLS_AS_ANNOTATION == "ALL":
+            return True
+        return False
+
+
     # hooks for django version >= 1.10
     def __call__(self, request):
 
@@ -50,9 +59,10 @@ class XRayMiddleware(object):
             recorder=xray_recorder,
             sampling_req=sampling_req,
         )
-
         if self.in_lambda_ctx:
             segment = xray_recorder.begin_subsegment(name)
+            # X-Ray can't search/filter subsegments on URL but it can search annotations
+            # So for lambda to be able to filter by annotation we add these as annotations
         else:
             segment = xray_recorder.begin_segment(
                 name=name,
@@ -64,23 +74,37 @@ class XRayMiddleware(object):
         segment.save_origin_trace_header(xray_header)
         segment.put_http_meta(http.URL, request.build_absolute_uri())
         segment.put_http_meta(http.METHOD, request.method)
+        if self._urls_as_annotation():
+            segment.put_annotation(http.URL, request.build_absolute_uri())
+            segment.put_annotation(http.METHOD, request.method)
 
         if meta.get(USER_AGENT_KEY):
             segment.put_http_meta(http.USER_AGENT, meta.get(USER_AGENT_KEY))
+            if self._urls_as_annotation():
+                segment.put_annotation(http.USER_AGENT, meta.get(USER_AGENT_KEY))
         if meta.get(X_FORWARDED_KEY):
             # X_FORWARDED_FOR may come from untrusted source so we
             # need to set the flag to true as additional information
             segment.put_http_meta(http.CLIENT_IP, meta.get(X_FORWARDED_KEY))
             segment.put_http_meta(http.X_FORWARDED_FOR, True)
+            if self._urls_as_annotation():
+                segment.put_annotation(http.CLIENT_IP, meta.get(X_FORWARDED_KEY))
+                segment.put_annotation(http.X_FORWARDED_FOR, True)
         elif meta.get(REMOTE_ADDR_KEY):
             segment.put_http_meta(http.CLIENT_IP, meta.get(REMOTE_ADDR_KEY))
+            if self._urls_as_annotation():
+                segment.put_annotation(http.CLIENT_IP, meta.get(REMOTE_ADDR_KEY))
 
         response = self.get_response(request)
         segment.put_http_meta(http.STATUS, response.status_code)
+        if self._urls_as_annotation():
+            segment.put_annotation(http.STATUS, response.status_code)
 
         if response.has_header(CONTENT_LENGTH_KEY):
             length = int(response[CONTENT_LENGTH_KEY])
             segment.put_http_meta(http.CONTENT_LENGTH, length)
+            if self._urls_as_annotation():
+                segment.put_annotation(http.CONTENT_LENGTH, length)
         response[http.XRAY_HEADER] = prepare_response_header(xray_header, segment)
 
         if self.in_lambda_ctx:
