@@ -1,6 +1,7 @@
 import logging
 
 from django.template import Template
+from django.utils.safestring import SafeString
 
 from aws_xray_sdk.core import xray_recorder
 
@@ -22,6 +23,10 @@ def patch_template():
         template_name = self.name or getattr(context, 'template_name', None)
         if template_name:
             name = str(template_name)
+            # SafeString are not properly serialized by jsonpickle,
+            # turn them back to str by adding a non-safe str.
+            if isinstance(name, SafeString):
+                name += ''
             subsegment = xray_recorder.current_subsegment()
             if subsegment:
                 subsegment.name = name
